@@ -70,10 +70,10 @@ def thanks(request, redirect_url=settings.LOGIN_REDIRECT_URL):
         if 'displayName' in guser:
             username = guser['displayName'].replace(' ', '_')
         user = User.objects.create_user(username, email, request.REQUEST['state'])
-        profile = GoogleProfile()
-        profile.user = user
-        profile.credential = credential
-        profile.save()
+    GoogleProfile.objects.get_or_create(
+        user=user,
+        credential=credential
+    )
 
     user.backend = 'django.contrib.auth.backends.ModelBackend'
     login(request, user)
